MapAdjacencyList

Struct MapAdjacencyList 

pub struct MapAdjacencyList<NI, E, M>
where NI: NodeIndex, E: NodesIterable<Node = NI>, M: MapTrait<NI, E>,
{ /* private fields */ }

Implementations

Source

impl<NI, E, M> MapAdjacencyList<NI, E, M>
where NI: NodeIndex, E: NodesIterable<Node = NI>, M: MapTrait<NI, E>,

pub fn new(nodes: M) -> Result<Self, GraphError<NI>>
where NI: Copy, Self: Graph<NI, Error = GraphError<NI>>,

Create new map adjacency list with validation

This function validates that all edge destinations exist in the node set. Returns an error if any edge references a non-existent node.

pub fn new_unchecked(nodes: M) -> Self