AStarConfig

Struct AStarConfig 

pub struct AStarConfig<OS, CF, GS> {
    pub open_set: OS,
    pub came_from: CF,
    pub g_score: GS,
}
Configuration structure for A* algorithm to avoid too many function parameters

Fields

open_set: OS

Map to track nodes in the open set with their f-scores

came_from: CF

Map to track the path (parent of each node)

g_score: GS

Map to store actual cost from start to each node