pub struct MapAdjacencyList<NI, E, M>{ /* private fields */ }Implementations
Sourceimpl<NI, E, M> MapAdjacencyList<NI, E, M>
impl<NI, E, M> MapAdjacencyList<NI, E, M>
Sourcepub fn new(nodes: M) -> Result<Self, GraphError<NI>>
pub fn new(nodes: M) -> Result<Self, GraphError<NI>>
Create new map adjacency list with validation
This function validates that all edge destinations exist in the node set. Returns an error if any edge references a non-existent node.
pub fn new_unchecked(nodes: M) -> Self