pub struct AStarConfig<OS, CF, GS> {
pub open_set: OS,
pub came_from: CF,
pub g_score: GS,
}Expand description
Configuration structure for A* algorithm to avoid too many function parameters
Fields
open_set: OSMap to track nodes in the open set with their f-scores
came_from: CFMap to track the path (parent of each node)
g_score: GSMap to store actual cost from start to each node