pub trait MutableEdges<NI: PartialEq> {
// Required methods
fn add_edge(&mut self, edge: (NI, NI)) -> Option<usize>;
fn remove_edge(&mut self, edge: (NI, NI)) -> Option<usize>;
}Expand description
Trait for edge collections that support adding and removing edges
This trait allows dynamic addition and removal of edges to/from an edge collection, returning the index where the edge was inserted/removed if successful.
Required Methods
fn add_edge(&mut self, edge: (NI, NI)) -> Option<usize>
fn remove_edge(&mut self, edge: (NI, NI)) -> Option<usize>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".